@@ -58,39 +58,13 @@ struct _GNCSearchInt64Private
     GtkWindow *parent;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(GNCSearchInt64, gnc_search_int64, GNC_TYPE_SEARCH_CORE_TYPE)
+
 #define _PRIVATE(o) \
    (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_SEARCH_INT64, GNCSearchInt64Private))
 
 static GNCSearchCoreTypeClass *parent_class;
 
-GType
-gnc_search_int64_get_type (void)
-{
-    static GType type = 0;
-
-    if (!type)
-    {
-        GTypeInfo type_info =
-        {
-            sizeof(GNCSearchInt64Class),      /* class_size */
-            NULL,   				/* base_init */
-            NULL,				/* base_finalize */
-            (GClassInitFunc)gnc_search_int64_class_init,
-            NULL,				/* class_finalize */
-            NULL,				/* class_data */
-            sizeof(GNCSearchInt64),		/* */
-            0,				/* n_preallocs */
-            (GInstanceInitFunc)gnc_search_int64_init,
-        };
-
-        type = g_type_register_static (GNC_TYPE_SEARCH_CORE_TYPE,
-                                       "GNCSearchInt64",
-                                       &type_info, 0);
-    }
-
-    return type;
-}
-
 static void
 gnc_search_int64_class_init (GNCSearchInt64Class *klass)
 {
@@ -110,8 +84,6 @@ gnc_search_int64_class_init (GNCSearchInt64Class *klass)
     gnc_search_core_type->get_widget = gncs_get_widget;
     gnc_search_core_type->get_predicate = gncs_get_predicate;
     gnc_search_core_type->clone = gncs_clone;
-
-    g_type_class_add_private(klass, sizeof(GNCSearchInt64Private));
 }
 
 static void
