@@ -54,39 +54,13 @@ struct _GNCSearchReconciledPrivate
     gpointer dummy;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE(GNCSearchReconciled, gnc_search_reconciled, GNC_TYPE_SEARCH_CORE_TYPE)
+
 #define _PRIVATE(o) \
    (G_TYPE_INSTANCE_GET_PRIVATE ((o), GNC_TYPE_SEARCH_RECONCILED, GNCSearchReconciledPrivate))
 
 static GNCSearchCoreTypeClass *parent_class;
 
-GType
-gnc_search_reconciled_get_type (void)
-{
-    static GType type = 0;
-
-    if (!type)
-    {
-        GTypeInfo type_info =
-        {
-            sizeof(GNCSearchReconciledClass), /* class_size */
-            NULL,   			        /* base_init */
-            NULL,				/* base_finalize */
-            (GClassInitFunc)gnc_search_reconciled_class_init,
-            NULL,				/* class_finalize */
-            NULL,				/* class_data */
-            sizeof(GNCSearchReconciled),	/* */
-            0,				/* n_preallocs */
-            (GInstanceInitFunc)gnc_search_reconciled_init,
-        };
-
-        type = g_type_register_static (GNC_TYPE_SEARCH_CORE_TYPE,
-                                       "GNCSearchReconciled",
-                                       &type_info, 0);
-    }
-
-    return type;
-}
-
 static void
 gnc_search_reconciled_class_init (GNCSearchReconciledClass *klass)
 {
@@ -104,8 +78,6 @@ gnc_search_reconciled_class_init (GNCSearchReconciledClass *klass)
     gnc_search_core_type->get_widget = gncs_get_widget;
     gnc_search_core_type->get_predicate = gncs_get_predicate;
     gnc_search_core_type->clone = gncs_clone;
-
-    g_type_class_add_private(klass, sizeof(GNCSearchReconciledPrivate));
 }
 
 static void
