@@ -32,28 +32,24 @@
 #include <config.h>
 
 #include <glib/gi18n.h>
-#if HAVE_KTOBLZCHECK_H
-#    include <ktoblzcheck.h>
+#include "gnc-ab-utils.h" /* for AQBANKING6 */
+#ifdef AQBANKING6
+# include <aqbanking/types/transaction.h>
+#else
+# include <aqbanking/jobsingletransfer.h>
+# include <aqbanking/jobsingledebitnote.h>
+# include <aqbanking/jobinternaltransfer.h>
+# include <aqbanking/jobsepatransfer.h>
+# include <aqbanking/jobsepadebitnote.h>
 #endif
-#include <aqbanking/jobsingletransfer.h>
-#include <aqbanking/jobsingledebitnote.h>
-#include <aqbanking/jobinternaltransfer.h>
-#include <aqbanking/jobsepatransfer.h>
-#include <aqbanking/jobsepadebitnote.h>
 
 #include <gnc-aqbanking-templates.h>
 #include "dialog-ab-trans.h"
 #include "dialog-transfer.h"
 #include "dialog-utils.h"
-#include "gnc-ab-utils.h"
 #include "gnc-amount-edit.h"
 #include "gnc-ui.h"
 
-#if AQBANKING_VERSION_INT > 50200 || ((AQBANKING_VERSION_INT == 50200) && (AQBANKING_VERSION_BUILD > 0))
-/** Defined for aqbanking > 5.2.0 */
-# define AQBANKING_VERSION_GREATER_5_2_0
-#endif
-
 /* This static indicates the debugging module that this .o belongs to.  */
 static QofLogModule log_module = G_LOG_DOMAIN;
 
@@ -69,14 +65,13 @@ static gboolean gnc_ab_trans_dialog_get_templ_helper(GtkTreeModel *model,
         gpointer data);
 
 static AB_TRANSACTION *gnc_ab_trans_dialog_fill_values(GncABTransDialog *td);
-static AB_JOB *gnc_ab_trans_dialog_get_available_empty_job(AB_ACCOUNT *ab_acc,
+static GNC_AB_JOB *gnc_ab_trans_dialog_get_available_empty_job(GNC_AB_ACCOUNT_SPEC *ab_acc,
         GncABTransType trans_type);
 
-static void gnc_ab_trans_dialog_check_ktoblzcheck(const GncABTransDialog *td,
+static void gnc_ab_trans_dialog_check_iban(const GncABTransDialog *td,
         const AB_TRANSACTION *trans);
 
 /* Callbacks - connected with GtkBuilder */
-G_MODULE_EXPORT void gnc_ab_trans_dialog_bankcode_changed_cb(GtkEditable *editable, gpointer user_data);
 G_MODULE_EXPORT void gnc_ab_trans_dialog_add_templ_cb(GtkButton *button, gpointer user_data);
 G_MODULE_EXPORT void gnc_ab_trans_dialog_moveup_templ_cb(GtkButton *button, gpointer user_data);
 G_MODULE_EXPORT void gnc_ab_trans_dialog_movedown_templ_cb(GtkButton *button, gpointer user_data);
@@ -111,7 +106,7 @@ struct _GncABTransDialog
     /* The dialog itself */
     GtkWidget *dialog;
     GtkWidget *parent;
-    AB_ACCOUNT *ab_acc;
+    GNC_AB_ACCOUNT_SPEC *ab_acc;
 
     /* Whether this is a transfer or a direct debit */
     GncABTransType trans_type;
@@ -151,11 +146,6 @@ struct _GncABTransDialog
 
     /* The gnucash transaction that got created here */
     Transaction *gnc_trans;
-
-#if HAVE_KTOBLZCHECK_H
-    /* object for Account number checking */
-    AccountNumberCheck *blzcheck;
-#endif
 };
 
 gboolean gnc_ab_trans_isSEPA(GncABTransType t)
@@ -196,11 +186,11 @@ gnc_ab_trans_dialog_fill_values(GncABTransDialog *td)
     AB_TRANSACTION *trans = AB_Transaction_new();
     AB_VALUE *value;
 
+#ifdef AQBANKING6
+    AB_Banking_FillTransactionFromAccountSpec(trans, td->ab_acc);
+#else
     AB_Transaction_FillLocalFromAccount(trans, td->ab_acc);
-    //AB_Transaction_SetLocalBankCode(trans, AB_Account_GetBankCode(td->ab_acc));
-    //AB_Transaction_SetLocalAccountNumber(
-    //  trans, AB_Account_GetAccountNumber(td->ab_acc));
-    //AB_Transaction_SetLocalCountry(trans, "DE");
+#endif
 
     if (gnc_ab_trans_isSEPA(td->trans_type))
     {
@@ -219,6 +209,17 @@ gnc_ab_trans_dialog_fill_values(GncABTransDialog *td)
                     trans, gtk_entry_get_text(GTK_ENTRY(td->recp_account_entry)));
     }
     AB_Transaction_SetRemoteCountry(trans, "DE");
+#ifdef AQBANKING6
+    AB_Transaction_SetRemoteName(
+        trans, gtk_entry_get_text(GTK_ENTRY(td->recp_name_entry)));
+
+    AB_Transaction_AddPurposeLine(
+        trans, gtk_entry_get_text(GTK_ENTRY(td->purpose_entry)));
+    AB_Transaction_AddPurposeLine(
+        trans, gtk_entry_get_text(GTK_ENTRY(td->purpose_cont_entry)));
+    AB_Transaction_AddPurposeLine(
+        trans, gtk_entry_get_text(GTK_ENTRY(td->purpose_cont2_entry)));
+#else
     AB_Transaction_AddRemoteName(
         trans, gtk_entry_get_text(GTK_ENTRY(td->recp_name_entry)), FALSE);
 
@@ -230,7 +231,7 @@ gnc_ab_trans_dialog_fill_values(GncABTransDialog *td)
         trans, gtk_entry_get_text(GTK_ENTRY(td->purpose_cont2_entry)), FALSE);
     AB_Transaction_AddPurpose(
         trans, gtk_entry_get_text(GTK_ENTRY(td->purpose_cont3_entry)), FALSE);
-
+#endif
     value = AB_Value_fromDouble(gnc_amount_edit_get_damount(
                                     GNC_AMOUNT_EDIT(td->amount_edit)));
     /* FIXME: Replace "EUR" by account-dependent string here. */
@@ -256,7 +257,7 @@ gnc_ab_trans_dialog_fill_values(GncABTransDialog *td)
 }
 
 GncABTransDialog *
-gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
+gnc_ab_trans_dialog_new(GtkWidget *parent, GNC_AB_ACCOUNT_SPEC *ab_acc,
                         gint commodity_scu, GncABTransType trans_type,
                         GList *templates)
 {
@@ -284,6 +285,14 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
 
     g_return_val_if_fail(ab_acc, NULL);
 
+#ifdef AQBANKING6
+    ab_ownername = AB_AccountSpec_GetOwnerName(ab_acc);
+    if (!ab_ownername)
+        ab_ownername = "";
+    ab_accountnumber = AB_AccountSpec_GetAccountNumber(ab_acc);
+    ab_bankcode = AB_AccountSpec_GetBankCode(ab_acc);
+    ab_bankname = _("(unknown)");
+#else
     ab_ownername = AB_Account_GetOwnerName(ab_acc);
     if (!ab_ownername)
         ab_ownername = "";
@@ -292,16 +301,13 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
     ab_bankname = AB_Account_GetBankName(ab_acc);
     if (!ab_bankname || !*ab_bankname)
         ab_bankname = _("(unknown)");
+#endif
 
     td = g_new0(GncABTransDialog, 1);
     td->parent = parent;
     td->ab_acc = ab_acc;
     td->trans_type = trans_type;
 
-#if HAVE_KTOBLZCHECK_H
-    td->blzcheck = AccountNumberCheck_new();
-#endif
-
     builder = gtk_builder_new();
     gnc_builder_add_from_file (builder, "dialog-ab.glade", "aqbanking_transaction_dialog");
     td->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "aqbanking_transaction_dialog"));
@@ -381,22 +387,7 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
         break;
 
     case SINGLE_DEBITNOTE:
-        gtk_label_set_text(GTK_LABEL (heading_label),
-                           _("Enter an Online Direct Debit Note"));
-
-        gtk_label_set_text(GTK_LABEL(recp_name_heading),
-                           _("Debited Account Owner"));
-        gtk_label_set_text(GTK_LABEL(recp_account_heading),
-                           _("Debited Account Number"));
-        gtk_label_set_text(GTK_LABEL(recp_bankcode_heading),
-                           _("Debited Account Bank Code"));
-
-        gtk_label_set_text(GTK_LABEL(orig_name_heading),
-                           _("Credited Account Owner"));
-        gtk_label_set_text(GTK_LABEL(orig_account_heading),
-                           _("Credited Account Number"));
-        gtk_label_set_text(GTK_LABEL(orig_bankcode_heading),
-                           _("Credited Account Bank Code"));
+        /* this case is no longer in use; don't introduce extra strings */
         break;
 
     case SEPA_DEBITNOTE:
@@ -437,8 +428,13 @@ gnc_ab_trans_dialog_new(GtkWidget *parent, AB_ACCOUNT *ab_acc,
     if (gnc_ab_trans_isSEPA(trans_type))
     {
         gtk_widget_set_sensitive(GTK_WIDGET(td->orig_name_entry), TRUE);
+#if AQBANKING6
+        ab_accountnumber = AB_AccountSpec_GetIban(ab_acc);
+        ab_bankcode = AB_AccountSpec_GetBic(ab_acc);
+#else
         ab_accountnumber = AB_Account_GetIBAN(ab_acc);
         ab_bankcode = AB_Account_GetBIC(ab_acc);
+#endif
         gtk_label_set_text(GTK_LABEL(orig_account_label), ab_accountnumber);
         gtk_label_set_text (GTK_LABEL (orig_bankcode_label), ab_bankcode);
     }
@@ -487,11 +483,12 @@ gnc_ab_trans_dialog_entry_set (GtkWidget* entry,
 }
 
 static void
-gnc_ab_trans_dialog_check_ktoblzcheck(const GncABTransDialog *td,
-                                      const AB_TRANSACTION *trans)
+gnc_ab_trans_dialog_check_iban(const GncABTransDialog *td,
+                               const AB_TRANSACTION *trans)
 {
     if (gnc_ab_trans_isSEPA(td->trans_type))
     {
+        /* Verify the correct IBAN bank code */
         int rv = AB_Banking_CheckIban(AB_Transaction_GetRemoteIban(trans));
         if (rv != 0) {
             gchar *message = g_strdup_printf(_("The internal check of the destination IBAN '%s' "
@@ -511,65 +508,9 @@ gnc_ab_trans_dialog_check_ktoblzcheck(const GncABTransDialog *td,
     }
     else
     {
-#ifndef HAVE_KTOBLZCHECK_H
-    return;
-#else
-    gint blzresult;
-    const char *blztext;
-    gchar* message;
-
-    ENTER(" ");
-
-    if (gnc_ab_trans_isSEPA(td->trans_type))
-    {
-        // FIXME: libktoblzcheck also has <iban.h>, maybe add this here?
-        LEAVE("No ktoblzcheck implemented for IBAN");
+        /* this case is no longer in use */
         return;
     }
-
-    blzresult = AccountNumberCheck_check(
-                    td->blzcheck,
-                    AB_Transaction_GetRemoteBankCode(trans),
-                    AB_Transaction_GetRemoteAccountNumber(trans));
-    switch (blzresult)
-    {
-    case 2:
-        message = g_strdup_printf(_("The internal check of the destination account number '%s' "
-                                    "at the specified bank with bank code '%s' failed. This means "
-                                    "the account number might contain an error."),
-                                  AB_Transaction_GetRemoteAccountNumber(trans),
-                                  AB_Transaction_GetRemoteBankCode(trans));
-        gnc_ab_trans_dialog_entry_set (td->recp_bankcode_entry, message,
-                                       "dialog-warning");
-        gnc_ab_trans_dialog_entry_set (td->recp_account_entry, message,
-                                       "dialog-warning");
-
-        blztext = "Kontonummer wahrscheinlich falsch";
-        break;
-    case 0:
-        blztext = "Kontonummer ok";
-        break;
-    case 3:
-        blztext = "bank unbekannt";
-        break;
-    case 1:
-    default:
-        blztext = "unbekannt aus unbekanntem grund";
-        break;
-    }
-
-    if (blzresult != 2)
-    {
-        gnc_ab_trans_dialog_entry_set (td->recp_bankcode_entry, "",
-                                       NULL);
-        gnc_ab_trans_dialog_entry_set (td->recp_account_entry, "",
-                                       NULL);
-    }
-
-    LEAVE("KtoBlzCheck said check is %d = %s",
-          blzresult, blztext ? blztext : "(none)");
-#endif
-    }
 }
 
 static void
@@ -598,10 +539,8 @@ gnc_ab_trans_dialog_verify_values(GncABTransDialog *td)
     // Verify that we have a local IBAN and BIC
     if (gnc_ab_trans_isSEPA(td->trans_type))
     {
-        const char* localBIC = AB_Transaction_GetLocalBic(td->ab_trans);
         const char* localIBAN = AB_Transaction_GetLocalIban(td->ab_trans);
-        if (!localBIC || !localIBAN
-                || (strlen(localBIC) == 0) || (strlen(localIBAN) == 0))
+        if (!localIBAN || (strlen(localIBAN) == 0))
         {
             const char* localBankCode = AB_Transaction_GetLocalBankCode(td->ab_trans);
             const char* localAccountCode = AB_Transaction_GetLocalAccountNumber(td->ab_trans);
@@ -669,7 +608,7 @@ gnc_ab_trans_dialog_verify_values(GncABTransDialog *td)
     }
     /* Check if account details are correct - gives warning only */
     if (values_ok)
-        gnc_ab_trans_dialog_check_ktoblzcheck(td, td->ab_trans);
+        gnc_ab_trans_dialog_check_iban(td, td->ab_trans);
 
     /* Check transaction value */
     if (AB_Value_GetValueAsDouble(AB_Transaction_GetValue(td->ab_trans))
@@ -705,27 +644,6 @@ gnc_ab_trans_dialog_verify_values(GncABTransDialog *td)
         g_free(purpose);
     }
 
-#if 0
-//    // AQBANKING_VERSION_INT >= 50307
-//    if (gnc_ab_trans_isSEPA(td->trans_type))
-//    {
-//        AB_USER *u = AH_Job_GetUser(j);
-//        uint32_t uflags;
-//            (AB_Transaction_CheckForSepaConformity(td->ab_trans, 0) != 0))
-    // need to check how to do this for aqbanking >= 5.3.7 when I have time
-    {
-        gnc_ab_trans_dialog_entry_set (td->recp_name_entry,
-                                       _("The text you entered contained at least one character that is invalid for a SEPA transaction. "
-                                         "In SEPA, unfortunately only exactly the following characters are allowed: "
-                                         "a...z, A...Z, 0...9, and the following punctuations: ' : ? , - ( + . ) / "
-                                         "\n\n"
-                                         "In particular, neither Umlauts nor an ampersand (&) is allowed, "
-                                         "neither in the recipient or sender name nor in any purpose line."),
-                                       "process-stop");
-        values_ok = FALSE;
-    }
-#endif
-
     gtk_widget_set_sensitive(td->exec_button, values_ok);
     gnc_ab_trans_dialog_clear_transaction(td);
 }
@@ -734,7 +652,7 @@ gint
 gnc_ab_trans_dialog_run_until_ok(GncABTransDialog *td)
 {
     gint result;
-    AB_JOB *job;
+    GNC_AB_JOB *job;
     const AB_TRANSACTION_LIMITS *joblimits;
     guint8 max_purpose_lines;
 
@@ -747,13 +665,11 @@ gnc_ab_trans_dialog_run_until_ok(GncABTransDialog *td)
     }
 
     /* Activate as many purpose entries as available for the job */
-    joblimits =
-#ifdef AQBANKING_VERSION_GREATER_5_2_0
-            AB_Job_GetFieldLimits
+#ifdef AQBANKING6
+    joblimits = AB_AccountSpec_GetTransactionLimitsForCommand(td->ab_acc, AB_Transaction_GetCommand(job));
 #else
-            AB_JobSingleTransfer_GetFieldLimits
+    joblimits = AB_Job_GetFieldLimits (job);
 #endif
-            (job);
     max_purpose_lines = joblimits ?
                         AB_TransactionLimits_GetMaxLinesPurpose(joblimits) : 2;
     gtk_widget_set_sensitive(td->purpose_cont_entry, max_purpose_lines > 1);
@@ -836,9 +752,6 @@ gnc_ab_trans_dialog_free(GncABTransDialog *td)
                                gnc_ab_trans_dialog_clear_templ_helper, NULL);
         g_object_unref(td->template_list_store);
     }
-#if HAVE_KTOBLZCHECK_H
-    AccountNumberCheck_delete(td->blzcheck);
-#endif
     g_free(td);
 }
 
@@ -892,11 +805,38 @@ gnc_ab_trans_dialog_get_ab_trans(const GncABTransDialog *td)
     return td->ab_trans;
 }
 
-static AB_JOB *
-gnc_ab_trans_dialog_get_available_empty_job(AB_ACCOUNT *ab_acc, GncABTransType trans_type)
+static GNC_AB_JOB *
+gnc_ab_trans_dialog_get_available_empty_job(GNC_AB_ACCOUNT_SPEC *ab_acc, GncABTransType trans_type)
 {
-    AB_JOB *job;
+    GNC_AB_JOB *job;
+#ifdef AQBANKING6
+    AB_TRANSACTION_COMMAND cmd = AB_Transaction_CommandUnknown;
 
+     switch (trans_type)
+     {
+     case SINGLE_DEBITNOTE: /* no longer in use */
+         cmd=AB_Transaction_CommandDebitNote;
+         break;
+     case SINGLE_INTERNAL_TRANSFER:
+         cmd=AB_Transaction_CommandInternalTransfer;
+         break;
+     case SEPA_TRANSFER:
+         cmd=AB_Transaction_CommandSepaTransfer;
+         break;
+     case SEPA_DEBITNOTE:
+         cmd=AB_Transaction_CommandSepaDebitNote;
+         break;
+     default:
+        cmd=AB_Transaction_CommandTransfer; /* no longer in use */
+         break;
+     };
+     if (!AB_AccountSpec_GetTransactionLimitsForCommand(ab_acc, cmd))
+         return NULL;
+
+     job = AB_Transaction_new();
+     AB_Transaction_SetCommand(job, cmd);
+     AB_Transaction_SetUniqueAccountId(job, AB_AccountSpec_GetUniqueId(ab_acc));
+#else
     switch (trans_type)
     {
     case SINGLE_DEBITNOTE:
@@ -905,73 +845,67 @@ gnc_ab_trans_dialog_get_available_empty_job(AB_ACCOUNT *ab_acc, GncABTransType t
     case SINGLE_INTERNAL_TRANSFER:
         job = AB_JobInternalTransfer_new(ab_acc);
         break;
-    case SEPA_TRANSFER:
-        job = AB_JobSepaTransfer_new(ab_acc);
+    case SINGLE_TRANSFER:
+        job = AB_JobSingleTransfer_new(ab_acc);
         break;
     case SEPA_DEBITNOTE:
         job = AB_JobSepaDebitNote_new(ab_acc);
         break;
-    case SINGLE_TRANSFER:
+    case SEPA_TRANSFER:
     default:
-        job = AB_JobSingleTransfer_new(ab_acc);
+        job = AB_JobSepaTransfer_new(ab_acc);
         break;
     };
-
-    if (!job || AB_Job_CheckAvailability(job
-#ifndef AQBANKING_VERSION_5_PLUS
-                                         , 0
-#endif
-                                        ))
+    if (!job || AB_Job_CheckAvailability(job))
     {
         if (job) AB_Job_free(job);
         return NULL;
     }
+#endif
     return job;
 }
 
-AB_JOB *
+GNC_AB_JOB *
 gnc_ab_trans_dialog_get_job(const GncABTransDialog *td)
 {
     g_return_val_if_fail(td, NULL);
     return gnc_ab_get_trans_job(td->ab_acc, td->ab_trans, td->trans_type);
 }
 
-AB_JOB *
-gnc_ab_get_trans_job(AB_ACCOUNT *ab_acc, const AB_TRANSACTION *ab_trans,
+GNC_AB_JOB *
+gnc_ab_get_trans_job(GNC_AB_ACCOUNT_SPEC *ab_acc,
+                     const AB_TRANSACTION *ab_trans,
                      GncABTransType trans_type)
 {
-    AB_JOB *job;
+    GNC_AB_JOB *job;
 
     g_return_val_if_fail(ab_acc && ab_trans, NULL);
 
+#ifdef AQBANKING6
     job = gnc_ab_trans_dialog_get_available_empty_job(ab_acc, trans_type);
     if (job)
     {
-#ifdef AQBANKING_VERSION_GREATER_5_2_0
-        AB_Job_SetTransaction(job, ab_trans);
+        AB_TRANSACTION *new_job;
+
+        /* merge transactions */
+        new_job=AB_Transaction_dup(ab_trans);
+        AB_Transaction_SetCommand(new_job, AB_Transaction_GetCommand(job));
+        AB_Transaction_SetUniqueAccountId(new_job,
+                                          AB_Transaction_GetUniqueAccountId(job));
+
+        AB_Transaction_free(job);
+        return new_job;
+    }
+    return NULL;
+
 #else
-        switch (trans_type)
-        {
-        case SINGLE_DEBITNOTE:
-            AB_JobSingleDebitNote_SetTransaction(job, ab_trans);
-            break;
-        case SINGLE_INTERNAL_TRANSFER:
-            AB_JobInternalTransfer_SetTransaction(job, ab_trans);
-            break;
-        case SEPA_TRANSFER:
-            AB_JobSepaTransfer_SetTransaction(job, ab_trans);
-            break;
-        case SEPA_DEBITNOTE:
-            AB_JobSepaDebitNote_SetTransaction(job, ab_trans);
-            break;
-        case SINGLE_TRANSFER:
-        default:
-            AB_JobSingleTransfer_SetTransaction(job, ab_trans);
-            break;
-        };
-#endif
+    job = gnc_ab_trans_dialog_get_available_empty_job(ab_acc, trans_type);
+    if (job)
+    {
+        AB_Job_SetTransaction(job, ab_trans);
     }
     return job;
+#endif
 }
 
 void
@@ -1026,65 +960,6 @@ gnc_ab_trans_dialog_templ_list_row_activated_cb(GtkTreeView *view,
     LEAVE(" ");
 }
 
-void
-gnc_ab_trans_dialog_bankcode_changed_cb(GtkEditable *editable, gpointer user_data)
-{
-#if HAVE_KTOBLZCHECK_H
-    GncABTransDialog *td = user_data;
-    const AccountNumberCheck_Record *record;
-    const gchar *input = gtk_entry_get_text(GTK_ENTRY(td->recp_bankcode_entry));
-
-    g_return_if_fail(td);
-
-    // FIXME: If this is a SEPA transaction, totally different verification
-    // rules apply anyway. There are some initial verification functions in
-    // <ktoblzcheck/iban.h>, but those need to be implemented here as well.
-    if (gnc_ab_trans_isSEPA(td->trans_type))
-        return;
-
-    ENTER("td=%p, input=%s", td, input);
-    record = AccountNumberCheck_findBank(td->blzcheck, input);
-
-    if (record)
-    {
-        const char *bankname = AccountNumberCheck_Record_bankName(record);
-        GError *error = NULL;
-        const char *ktoblzcheck_encoding =
-#ifdef KTOBLZCHECK_VERSION_MAJOR
-            /* This version number macro has been added in ktoblzcheck-1.10, but
-             * this function exists already since ktoblzcheck-1.7, so we're on
-             * the safe side. */
-            AccountNumberCheck_stringEncoding()
-#else
-            /* Every ktoblzcheck release before 1.10 is guaranteed to return
-             * strings only in ISO-8859-15. */
-            "ISO-8859-15"
-#endif
-            ;
-        gchar *utf8_bankname = g_convert(bankname, strlen(bankname), "UTF-8",
-                                         ktoblzcheck_encoding, NULL, NULL,
-                                         &error);
-
-        if (error)
-        {
-            g_critical("Error converting bankname \"%s\" to UTF-8", bankname);
-            g_error_free (error);
-            /* Conversion was erroneous, so don't use the string */
-            utf8_bankname = g_strdup(_("(unknown)"));
-        }
-        gtk_label_set_text(GTK_LABEL(td->recp_bankname_label),
-                           *utf8_bankname ? utf8_bankname : _("(unknown)"));
-        DEBUG("Found: %s", utf8_bankname);
-        g_free(utf8_bankname);
-    }
-    else
-    {
-        gtk_label_set_text(GTK_LABEL(td->recp_bankname_label), _("(unknown)"));
-    }
-    gnc_ab_trans_dialog_verify_values(td);
-    LEAVE(" ");
-#endif
-}
 
 struct _FindTemplData
 {
