@@ -40,7 +40,8 @@
   ;; It also dumps the render into /tmp/XX-YY.html where XX is the
   ;; test prefix and YY is the test title.
 
-  (let* ((template (gnc:find-report-template uuid))
+  (let* ((template (or (gnc:find-report-template uuid)
+                       (error "report not found:" uuid)))
          (constructor (record-constructor <report>))
          (report (constructor uuid "bar" options #t #t #f #f ""))
          (renderer (gnc:report-template-renderer template))
@@ -81,10 +82,11 @@
                                 (strip-string render strip-tag)
                                 render)
                             #:trim-whitespace? #t
-                            #:entities '((nbsp . "\xa0"))))
+                            #:entities '((nbsp . "\xa0")
+                                         (ndash . "­"))))
       (lambda (k . args)
-        (format #t "*** XML error: ~a ~a\n~a"
-                prefix test-title
+        (format #t "*** XML error: ~a ~a: ~a / ~a\n~a"
+                prefix test-title k args
                 (gnc:html-render-options-changed options #t))
         (throw k args)))))
 
