@@ -322,10 +322,9 @@
          (parent-balance-mode (get-option gnc:pagename-display
                                            optname-parent-balance-mode))
          (parent-total-mode
-	  (car
-	   (assoc-ref '((t #t) (f #f) (canonically-tabbed canonically-tabbed))
-		      (get-option gnc:pagename-display
-				  optname-parent-total-mode))))
+	  (assq-ref '((t . #t) (f . #f) (canonically-tabbed . canonically-tabbed))
+		    (get-option gnc:pagename-display
+				optname-parent-total-mode)))
          (show-zb-accts? (get-option gnc:pagename-display
 				     optname-show-zb-accts))
          (omit-zb-bals? (get-option gnc:pagename-display
@@ -406,11 +405,7 @@
 	 1 "total-number-cell")
 	)
       )
-    ;; (gnc:sum-collector-stocks balance report-commodity exchange-fn)
-    ;; Hey! Look at that! This rolls the stocks into the balance!
-    ;; Can anyone think of a reason why this would be desirable?
-    ;; None come to (my) mind.  Perhaps this should be a report option?
-    
+
     ;; Wrapper around gnc:html-table-append-ruler! since we call it so
     ;; often.
     (define (add-rule table)
@@ -733,8 +728,6 @@
 	  (gnc:report-percent-done 100)
 	  
 	  ;; if sending the report to a file, do so now
-	  ;; however, this still doesn't seem to get around the
-	  ;; colspan bug... cf. gnc:colspans-are-working-right
 	  (if filename
 	      (let* ((port (open-output-file filename)))
                 (gnc:display-report-list-item
