@@ -227,31 +227,191 @@ gnc_is_new_book (void)
                             ? TRUE : FALSE);
 }
 
-#define OPTION_TAXUS_NAME "book/tax_US/name"
-#define OPTION_TAXUS_TYPE "book/tax_US/type"
+#define OPTION_TAXUS_NAME "tax_US/name"
+#define OPTION_TAXUS_TYPE "tax_US/type"
+#define OLD_OPTION_TAXUS_NAME "book/tax_US/name"
+#define OLD_OPTION_TAXUS_TYPE "book/tax_US/type"
 
 void
-gnc_set_current_book_tax_name (const gchar *tax_name)
+gnc_set_current_book_tax_name_type (gboolean name_changed, const gchar *tax_name,
+                                    gboolean type_changed, const gchar *tax_type)
 {
-    qof_book_set_string_option(gnc_get_current_book(), OPTION_TAXUS_NAME, tax_name);
+    if (name_changed)
+    {
+        if (type_changed)
+        {
+            QofBook* book = gnc_get_current_book();
+            if ((g_strcmp0 (tax_name, "") == 0) ||
+                (tax_name == NULL))
+            { /* change to no name */
+                if ((g_strcmp0 (tax_type, "Other") == 0) ||
+                    (g_strcmp0 (tax_type, "") == 0) ||
+                    (tax_type == NULL))
+                { /* need to delete both name and type and the "tax_US" frame */
+                    qof_book_set_string_option(book, OPTION_TAXUS_NAME, NULL);
+                    qof_book_set_string_option(book, OPTION_TAXUS_TYPE, NULL);
+                    qof_book_option_frame_delete(book, "tax_US");
+                }
+                else
+                { /* delete the name & change the type; keep the "tax_US" frame */
+                    qof_book_set_string_option(book, OPTION_TAXUS_NAME, NULL);
+                    qof_book_set_string_option(book, OPTION_TAXUS_TYPE, tax_type);
+                }
+            }
+            else /* new name */
+            {
+                if ((g_strcmp0 (tax_type, "Other") == 0) ||
+                    (g_strcmp0 (tax_type, "") == 0) ||
+                    (tax_type == NULL))
+                { /* delete the type & change the name; keep the "tax_US" frame */
+                    qof_book_set_string_option(book, OPTION_TAXUS_TYPE, NULL);
+                    qof_book_set_string_option(book, OPTION_TAXUS_NAME, tax_name);
+                }
+                else /* and new type */
+                { /* change the name & change the type */
+                    qof_book_set_string_option(book, OPTION_TAXUS_NAME, tax_name);
+                    qof_book_set_string_option(book, OPTION_TAXUS_TYPE, tax_type);
+                }
+            }
+        }
+        else /* no type change but name changed */
+        {
+            QofBook* book = gnc_get_current_book();
+            if ((g_strcmp0 (tax_name, "") == 0) ||
+                (tax_name == NULL))
+            { /* change to no name */
+                if ((g_strcmp0 (tax_type, "Other") == 0) ||
+                    (g_strcmp0 (tax_type, "") == 0) ||
+                    (tax_type == NULL))
+                { /* delete the name; there is no type; deleted the "tax_US" frame */
+                    qof_book_set_string_option(book, OPTION_TAXUS_NAME, NULL);
+                    qof_book_option_frame_delete(book, "tax_US");
+                }
+                else
+                { /* need to delete the name and keep "tax_US" frame */
+                    qof_book_set_string_option(book, OPTION_TAXUS_NAME, NULL);
+                }
+            }
+            else
+            { /* change the name & keep "tax_US" frame */
+                qof_book_set_string_option(book, OPTION_TAXUS_NAME, tax_name);
+            }
+        }
+   }
+   else /* no name change */
+   {
+        if (type_changed)
+        {
+            QofBook* book = gnc_get_current_book();
+            if ((g_strcmp0 (tax_type, "Other") == 0) ||
+                (g_strcmp0 (tax_type, "") == 0) ||
+                (tax_type == NULL))
+            {
+                if ((g_strcmp0 (tax_name, "") == 0) ||
+                    (tax_name == NULL))
+                {/* delete the type; there is no name; delete the "tax_US" frame */
+                    qof_book_set_string_option(book, OPTION_TAXUS_TYPE, NULL);
+                    qof_book_option_frame_delete(book, "tax_US");
+                }
+                else
+                { /* need to delete the type and keep "tax_US" frame */
+                    qof_book_set_string_option(book, OPTION_TAXUS_TYPE, NULL);
+                }
+            }
+            else
+            { /* change the type & keep "tax_US" frame */
+                qof_book_set_string_option(book, OPTION_TAXUS_TYPE, tax_type);
+            }
+        } /*else no name and no type change - do nothing */
+   }
 }
 
 const gchar *
 gnc_get_current_book_tax_name (void)
 {
-    return qof_book_get_string_option(gnc_get_current_book(), OPTION_TAXUS_NAME);
-}
-
-void
-gnc_set_current_book_tax_type (const gchar *tax_type)
-{
-    qof_book_set_string_option(gnc_get_current_book(), OPTION_TAXUS_TYPE, tax_type);
+    QofBook* book = gnc_get_current_book();
+    const char* tax_name =
+        qof_book_get_string_option(book, OPTION_TAXUS_NAME);
+    if (tax_name)
+    {
+        return tax_name;
+    }
+    else
+    {
+        const char* old_option_taxus_name =
+            qof_book_get_string_option(book, OLD_OPTION_TAXUS_NAME);
+        if (old_option_taxus_name)
+        {
+            char* taxus_name = g_strdup(old_option_taxus_name);
+            const char* old_option_taxus_type =
+                qof_book_get_string_option(book, OLD_OPTION_TAXUS_TYPE);
+            if (old_option_taxus_type)
+            { /* switch both name and type and remove unused frames */
+                char* taxus_type = g_strdup(old_option_taxus_type);
+                qof_book_set_string_option(book, OPTION_TAXUS_NAME, taxus_name);
+                qof_book_set_string_option(book, OLD_OPTION_TAXUS_NAME, NULL);
+                qof_book_set_string_option(book, OPTION_TAXUS_TYPE, taxus_type);
+                qof_book_set_string_option(book, OLD_OPTION_TAXUS_TYPE, NULL);
+                qof_book_option_frame_delete(book, "book/tax_US");
+                qof_book_option_frame_delete(book, "book");
+                g_free (taxus_type);
+            }
+            else
+            { /* switch just name and remove unused frames */
+                qof_book_set_string_option(book, OPTION_TAXUS_NAME, taxus_name);
+                qof_book_set_string_option(book, OLD_OPTION_TAXUS_NAME, NULL);
+                qof_book_option_frame_delete(book, "book/tax_US");
+                qof_book_option_frame_delete(book, "book");
+            }
+            g_free (taxus_name);
+            return qof_book_get_string_option(book, OPTION_TAXUS_NAME);
+        }
+        return NULL;
+    }
 }
 
 const gchar *
 gnc_get_current_book_tax_type (void)
 {
-    return qof_book_get_string_option(gnc_get_current_book(), OPTION_TAXUS_TYPE);
+    QofBook* book = gnc_get_current_book();
+    const char* tax_type =
+        qof_book_get_string_option(book, OPTION_TAXUS_TYPE);
+    if (tax_type)
+    {
+        return tax_type;
+    }
+    else
+    {
+        const char* old_option_taxus_type =
+            qof_book_get_string_option(book, OLD_OPTION_TAXUS_TYPE);
+        if (old_option_taxus_type)
+        {
+            char* taxus_type = g_strdup(old_option_taxus_type);
+            const char* old_option_taxus_name =
+                qof_book_get_string_option(book, OLD_OPTION_TAXUS_NAME);
+            if (old_option_taxus_name)
+            { /* switch both name and type and remove unused frames */
+                char* taxus_name = g_strdup(old_option_taxus_name);
+                qof_book_set_string_option(book, OPTION_TAXUS_NAME, taxus_name);
+                qof_book_set_string_option(book, OLD_OPTION_TAXUS_NAME, NULL);
+                qof_book_set_string_option(book, OPTION_TAXUS_TYPE, taxus_type);
+                qof_book_set_string_option(book, OLD_OPTION_TAXUS_TYPE, NULL);
+                qof_book_option_frame_delete(book, "book/tax_US");
+                qof_book_option_frame_delete(book, "book");
+                g_free (taxus_name);
+            }
+            else
+            { /* switch just type and remove unused frames */
+                qof_book_set_string_option(book, OPTION_TAXUS_TYPE, taxus_type);
+                qof_book_set_string_option(book, OLD_OPTION_TAXUS_TYPE, NULL);
+                qof_book_option_frame_delete(book, "book/tax_US");
+                qof_book_option_frame_delete(book, "book");
+            }
+            g_free (taxus_type);
+            return qof_book_get_string_option(book, OPTION_TAXUS_TYPE);
+        }
+        return NULL;
+    }
 }
 
 /** Calls gnc_book_option_num_field_source_change to initiate registered
@@ -727,20 +887,6 @@ gnc_ui_account_get_tax_info_sub_acct_string (const Account *account)
         return NULL;
 }
 
-static const char *
-string_after_colon (const char *msgstr)
-{
-    const char *string_at_colon;
-    g_assert(msgstr);
-    string_at_colon = strchr(msgstr, ':');
-    if (string_at_colon)
-        return string_at_colon + 1;
-    else
-        /* No colon found; we assume the translation contains only the
-           part after the colon, similar to the disambiguation prefixes */
-        return msgstr;
-}
-
 /********************************************************************\
  * gnc_get_reconcile_str                                            *
  *   return the i18n'd string for the given reconciled flag         *
@@ -754,22 +900,15 @@ gnc_get_reconcile_str (char reconciled_flag)
     switch (reconciled_flag)
     {
     case NREC:
-        /* Translators: For the following strings, the single letters
-           after the colon are abbreviations of the word before the
-           colon. You should only translate the letter *after* the colon. */
-        return string_after_colon(_("not cleared:n"));
+        return C_("Reconciled flag 'not cleared'", "n");
     case CREC:
-        /* Translators: Please only translate the letter *after* the colon. */
-        return string_after_colon(_("cleared:c"));
+        return C_("Reconciled flag 'cleared'", "c");
     case YREC:
-        /* Translators: Please only translate the letter *after* the colon. */
-        return string_after_colon(_("reconciled:y"));
+        return C_("Reconciled flag 'reconciled'", "y");
     case FREC:
-        /* Translators: Please only translate the letter *after* the colon. */
-        return string_after_colon(_("frozen:f"));
+        return C_("Reconciled flag 'frozen'", "f");
     case VREC:
-        /* Translators: Please only translate the letter *after* the colon. */
-        return string_after_colon(_("void:v"));
+        return C_("Reconciled flag 'void'", "v");
     default:
         PERR("Bad reconciled flag\n");
         return NULL;
