@@ -14,7 +14,7 @@
  *                                                                  *
  * You should have received a copy of the GNU General Public License*
  * along with this program; if not, you can retrieve it from        *
- * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html            *
+ * https://www.gnu.org/licenses/old-licenses/gpl-2.0.html            *
  * or contact:                                                      *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
@@ -29,6 +29,7 @@ extern "C"
 #include <config.h>
 #include "platform.h"
 #include <string.h>
+#include <stdlib.h>
 #include <sys/time.h>
 #include <glib.h>
 #include <unittest-support.h>
@@ -1407,20 +1408,15 @@ static gchar*
 format_timestring (time64 t, TZOffset tz)
 {
     static const unsigned tzlen = MAX_DATE_LENGTH - 26;
-    char *fmt = "%Y-%m-%d %H:%M:%S %z";
-    struct tm tm;
+    char *fmt = "%Y-%m-%d %H:%M:%S";
+    struct tm *tm;
     char buf[MAX_DATE_LENGTH + 1];
     char tzbuf[tzlen];
     memset(tzbuf, 0, sizeof(tzbuf));
-    gnc_localtime_r(&t, &tm);
-#if PLATFORM(WINDOWS)
-    strftime(tzbuf, sizeof(tzbuf), "%Z", &tm);
-#else
-    strftime(tzbuf, sizeof(tzbuf), "%z", &tm);
-#endif
+    tm = gnc_gmtime(&t);
     memset (buf, 0, sizeof(buf));
-    strftime(buf, sizeof(buf), fmt, &tm);
-
+    strftime(buf, sizeof(buf), fmt, tm);
+    free(tm);
     return g_strdup(buf);
 }
 
